@@ -15,6 +15,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from fabric.api import local as local_cmd  # import local with alternate name
+from instanceinfo import InstanceInfo
+import distutils.sysconfig
+from git import Repo
+import sys
+import os
+from time import gmtime, strftime
+from fabric.api import *
 import logging
 logger = logging.getLogger(__name__)
 handler = logging.StreamHandler()
@@ -24,19 +32,9 @@ handler.setFormatter(formatter)
 logger.addHandler(handler)
 logger.setLevel(logging.INFO)
 
-from fabric.api import *
-
-from time import gmtime, strftime
-import os
-import sys
-from git import Repo
-import distutils.sysconfig
-from instanceinfo import InstanceInfo
-
 
 # Use bash for fabric local commands, per
 # http://www.booneputney.com/development/fabric-run-local-bash-shell/
-from fabric.api import local as local_cmd  # import local with alternate name
 
 # create new local command, with the shell set to /bin/bash
 
@@ -48,7 +46,9 @@ def local(command_string):
 class FabricException(Exception):
     pass
 
-TRUTH_VALUES = ['True', 'TRUE', '1', 'true', 't', 'Yes','YES', 'yes', 'y']  # arguments in fab are always strings
+
+TRUTH_VALUES = ['True', 'TRUE', '1', 'true', 't', 'Yes',
+                'YES', 'yes', 'y']  # arguments in fab are always strings
 FALSE_VALUES = ['False', 'FALSE', '0', 'false', 'f', 'No', 'NO', 'no', 'n']
 
 # Set some global defaults for all operations.
@@ -56,7 +56,7 @@ FALSE_VALUES = ['False', 'FALSE', '0', 'false', 'f', 'No', 'NO', 'no', 'n']
 #
 env.connection_attempts = os.getenv('dcCodeDeployConnectionAttempts', 3)
 
-dcSharedDir=os.getenv('dcSharedDir', '~')
+dcSharedDir = os.getenv('dcSharedDir', '~')
 
 #
 # These settings may be altered either via an ENV var or via a fab task.
@@ -65,16 +65,19 @@ dcSharedDir=os.getenv('dcSharedDir', '~')
 #
 # Allow different users for target instance access.
 #
-env.user = os.getenv('dcCodeDeployUser','ubuntu')
+env.user = os.getenv('dcCodeDeployUser', 'ubuntu')
+
 
 @task
 def set_user(loginName):
     env.user = loginName
 
+
 #
 # Allow different organization (customer) for target instance access.
 #
-ORG = os.getenv('dcCodeDeployOrg','')
+ORG = os.getenv('dcCodeDeployOrg', '')
+
 
 @task
 def set_org(organization):
@@ -83,14 +86,15 @@ def set_org(organization):
 
 
 #
-# Look for this setting from the calling environment. 
+# Look for this setting from the calling environment.
 # E.g. for Jenkins. Note that in any Jenkins job, environment variables can come from one of three places:
 #     globally (from manage Jenkins, global properties)
 #     per job, via either a bash export at the beginning of the job or the environment injector plugin,
 #     per fab invocation, via the follow set_ip_mode fab task.
 # If this doesn't make any sense, well ....
 #
-IP_MODE=os.getenv('dcCodeDeployIPMode', 'public')
+IP_MODE = os.getenv('dcCodeDeployIPMode', 'public')
+
 
 @task
 def set_ip_mode(mode):
@@ -98,19 +102,23 @@ def set_ip_mode(mode):
     if mode in ['public', 'private']:
         IP_MODE = mode
 
+
 #
 #  Establish either an individual ssh key, or a path for all private ssh keys.
 #
-env.key_filename=os.getenv('dcCodeDeployKeyFilename','')
+env.key_filename = os.getenv('dcCodeDeployKeyFilename', '')
+
 
 @task
 def set_access_key(accessKey):
     env.key_filename = [accessKey]
 
+
 #
 #  Establish either an individual ssh key, or a path for all private ssh keys.
 #
-ENVIRONMENT=os.getenv('dcCodeDeployEnvironment','')
+ENVIRONMENT = os.getenv('dcCodeDeployEnvironment', '')
+
 
 @task
 def set_environment(this_environment):
@@ -118,7 +126,8 @@ def set_environment(this_environment):
     ENVIRONMENT = this_environment
 
 
-ACCESS_KEY_PATH=os.getenv('dcCodeDeployKeyPath', '~/.ssh')
+ACCESS_KEY_PATH = os.getenv('dcCodeDeployKeyPath', '~/.ssh')
+
 
 @task
 def set_access_key_path(anAccessKeyPath):
@@ -141,6 +150,8 @@ TAR_NAME = "devops"
 #  appname is application name, such as "fresco", "topopps", "mojo", etc.
 #  action is the deferred action needed, such as "deploy", "security-updates", etc.
 #  region is aws region
+
+
 @task
 def set_hosts(type, primary=None, appname=None, action=None, region=None,
               shard=None, aRole=None):
@@ -149,7 +160,7 @@ def set_hosts(type, primary=None, appname=None, action=None, region=None,
 
     instances = InstanceInfo(ORG, ACCESS_KEY_PATH, regions, dcSharedDir)
 
-    tags={}
+    tags = {}
     if type:
         tags["Type"] = [e for e in type.split(' ')]
     tags["Env"] = [ENVIRONMENT]
@@ -173,7 +184,8 @@ def set_hosts(type, primary=None, appname=None, action=None, region=None,
         elif instance.PrivatePort:
             env.port = instance.PrivatePort
 
-    env.hosts = [instance.PublicIpAddress if ((IP_MODE == 'public') and instance.PublicIpAddress) else instance.PrivateIpAddress for instance in targets]
+    env.hosts = [instance.PublicIpAddress if (
+        (IP_MODE == 'public') and instance.PublicIpAddress) else instance.PrivateIpAddress for instance in targets]
     env.host_names = [instance.InstanceName for instance in targets]
     env.key_filename = instances.getListOfKeys()
 
@@ -189,7 +201,7 @@ def set_one_host(type, primary=None, appname=None, action=None, region=None,
     regions = [e for e in region.split(' ')] if region else []
     instances = InstanceInfo(ORG, ACCESS_KEY_PATH, regions, dcSharedDir)
 
-    tags={}
+    tags = {}
     if type:
         tags["Type"] = [e for e in type.split(' ')]
     tags["Env"] = [ENVIRONMENT]
@@ -200,7 +212,7 @@ def set_one_host(type, primary=None, appname=None, action=None, region=None,
         tags["role"] = [aRole]
     if shard:
         tags["Shard"] = [e for e in shard.split(' ')]
- 
+
     targets = instances.getInstanceInfo(tags)
     instance = targets[0]
     targets = [instance]
@@ -212,11 +224,11 @@ def set_one_host(type, primary=None, appname=None, action=None, region=None,
         env.port = instance.PublicPort
     elif instance.PrivatePort:
         env.port = instance.PrivatePort
-    env.hosts = [instance.PublicIpAddress if ((IP_MODE == 'public') and instance.PublicIpAddress) else instance.PrivateIpAddress]
+    env.hosts = [instance.PublicIpAddress if (
+        (IP_MODE == 'public') and instance.PublicIpAddress) else instance.PrivateIpAddress]
     env.host_names = [instance.InstanceName]
     env.key_filename = instance.DestKey
 
-
     _log_hosts(targets)
 
 
@@ -227,7 +239,7 @@ def set_one_host_per_shard(type, primary=None, appname=None, action=None,
     regions = [e for e in region.split(' ')] if region else []
     instances = InstanceInfo(ORG, ACCESS_KEY_PATH, regions, dcSharedDir)
 
-    tags={}
+    tags = {}
     if type:
         tags["Type"] = [e for e in type.split(' ')]
     tags["Env"] = [ENVIRONMENT]
@@ -238,7 +250,7 @@ def set_one_host_per_shard(type, primary=None, appname=None, action=None,
         tags["role"] = [aRole]
     if shard:
         tags["Shard"] = [e for e in shard.split(' ')]
- 
+
     targets = instances.getInstanceInfo(tags)
 
 # Remove any duplicate hosts from each shard, leaving only one per shard
@@ -258,7 +270,8 @@ def set_one_host_per_shard(type, primary=None, appname=None, action=None,
         elif instance.PrivatePort:
             env.port = instance.PrivatePort
 
-    env.hosts = [instance.PublicIpAddress if ((IP_MODE == 'public') and instance.PublicIpAddress) else instance.PrivateIpAddress for instance in targets]
+    env.hosts = [instance.PublicIpAddress if (
+        (IP_MODE == 'public') and instance.PublicIpAddress) else instance.PrivateIpAddress for instance in targets]
     env.host_names = [instance.InstanceName for instance in targets]
     env.key_filename = instances.getListOfKeys()
 
@@ -291,19 +304,18 @@ def _log_hosts(instances):
 @task
 def build(branch='', ngBuild='', ngApp='', angularBuild='', angularEnv='', angularPostBuild='', installPath='.', node=''):
 
-
  # Need to give each build job it's own yarn cache, as the yarn cache is not safe for concurrent builds.
  # For more info: https://github.com/yarnpkg/yarn/issues/683#issuecomment-346038525
-    yarn_cache=os.getenv('PWD','') + '@tmp/.yarn_cache'
+    yarn_cache = os.getenv('PWD', '') + '@tmp/.yarn_cache'
 #    local('yarn config set cache-folder %s' % yarn_cache)
 
     with lcd(installPath):
 
-    # ensure yarn installs all build tools
+        # ensure yarn installs all build tools
         local("pwd")
         local('yarn --production=false --no-progress --non-interactive')
 
-# ngBuild works for both app and angular builds. 
+# ngBuild works for both app and angular builds.
 # If angularEnv is specified, then yarn is called with `--configuration=<angularEnv>`, suitable for angular builds.
 # Otherwise call without, so suitable for app builds.
         if ngBuild:
@@ -311,7 +323,8 @@ def build(branch='', ngBuild='', ngApp='', angularBuild='', angularEnv='', angul
             local('yarn build %s %s' % (options, ngApp))
             local('cp {package.json,yarn.lock,knexfile.js} dist/')
             local('cp -R migrations/ dist')
-            local('if [ -d "apps/%s/config" ]; then cp -R "apps/%s/config" "dist/apps/%s/"; fi' % (ngApp,ngApp,ngApp))
+            local('if [ -d "apps/%s/config" ]; then cp -R "apps/%s/config" "dist/apps/%s/"; fi' %
+                  (ngApp, ngApp, ngApp))
 
 #
 # deprecated, as `ngBuild` now handles both app and angular builds are handled in `ngBuild`.
@@ -325,8 +338,10 @@ def build(branch='', ngBuild='', ngApp='', angularBuild='', angularEnv='', angul
 # this is for the legacy, non-angular app builds
         elif node:
             local('npm run dist')
-            local('if [[ -d "config" ]]; then echo "<collecting config>" ; rsync -ra --stats config/ dist/config; fi;')
-            local('if [[ -d "src/public" ]]; then echo "<collecting public>" ; rsync -ra --stats src/public/ dist/public; fi;')
+            local(
+                'if [[ -d "config" ]]; then echo "<collecting config>" ; rsync -ra --stats config/ dist/config; fi;')
+            local(
+                'if [[ -d "src/public" ]]; then echo "<collecting public>" ; rsync -ra --stats src/public/ dist/public; fi;')
 
         local('du -hd1 %s' % yarn_cache)
 
@@ -347,11 +362,13 @@ def build2(javaEnv, dirs, prodSecrets="False", shard="", buildApi="True", buildW
         local('cp api/target/*SNAPSHOT.jar deploy/api/')
 
         if prodSecrets in TRUTH_VALUES:
-            local('aws s3 cp s3://topopps-prod-x/keyset-%s-s%s.json deploy/api/config/keyset.json' % (javaEnv, shard))
-            local('aws s3 cp s3://topopps-prod-x/application-%s-s%s.yml deploy/api/config/application-%s.yml' % (javaEnv, shard, javaEnv))
+            local('aws s3 cp s3://topopps-prod-x/keyset-%s-s%s.json deploy/api/config/keyset.json' %
+                  (javaEnv, shard))
+            local('aws s3 cp s3://topopps-prod-x/application-%s-s%s.yml deploy/api/config/application-%s.yml' %
+                  (javaEnv, shard, javaEnv))
         else:
             local('cp config/keyset-%s.json deploy/api/config/keyset.json' % javaEnv)
-    	    local('cp config/application-%s.yml deploy/api/config/' % javaEnv)
+            local('cp config/application-%s.yml deploy/api/config/' % javaEnv)
 
     if buildScheduler in TRUTH_VALUES:
         local('mkdir -p deploy/scheduler-worker/config')
@@ -363,10 +380,13 @@ def build2(javaEnv, dirs, prodSecrets="False", shard="", buildApi="True", buildW
         local('cp scheduler-worker/target/*SNAPSHOT.jar deploy/scheduler-worker/')
         if prodSecrets in TRUTH_VALUES:
             local('aws s3 cp s3://topopps-prod-x/keyset-%s-s%s.json deploy/scheduler-worker/config/keyset.json' % (javaEnv, shard))
-            local('aws s3 cp s3://topopps-prod-x/application-%s-s%s.yml deploy/scheduler-worker/config/application-%s.yml' % (javaEnv, shard, javaEnv))
+            local('aws s3 cp s3://topopps-prod-x/application-%s-s%s.yml deploy/scheduler-worker/config/application-%s.yml' %
+                  (javaEnv, shard, javaEnv))
         else:
-            local('cp config/keyset-%s.json deploy/scheduler-worker/config/keyset.json' % javaEnv)
-            local('cp config/application-%s.yml deploy/scheduler-worker/config/' % javaEnv)
+            local(
+                'cp config/keyset-%s.json deploy/scheduler-worker/config/keyset.json' % javaEnv)
+            local(
+                'cp config/application-%s.yml deploy/scheduler-worker/config/' % javaEnv)
 
     if buildWorker in TRUTH_VALUES:
         local('mkdir -p deploy/worker/config')
@@ -377,17 +397,18 @@ def build2(javaEnv, dirs, prodSecrets="False", shard="", buildApi="True", buildW
         local('cp -r worker/target/lib/ deploy/worker/')
         local('cp worker/target/*SNAPSHOT.jar deploy/worker/')
         if prodSecrets in TRUTH_VALUES:
-            local('aws s3 cp s3://topopps-prod-x/keyset-%s-s%s.json deploy/worker/config/keyset.json' % (javaEnv, shard))
-    	    local('aws s3 cp s3://topopps-prod-x/application-%s-s%s.yml deploy/worker/config/application-%s.yml' % (javaEnv, shard, javaEnv))
-    	    local('aws s3 cp s3://topopps-prod-x/application-%s-s%s-worker.yml deploy/worker/config/application-%s-worker.yml' % (javaEnv, shard, javaEnv))
+            local('aws s3 cp s3://topopps-prod-x/keyset-%s-s%s.json deploy/worker/config/keyset.json' %
+                  (javaEnv, shard))
+            local('aws s3 cp s3://topopps-prod-x/application-%s-s%s.yml deploy/worker/config/application-%s.yml' %
+                  (javaEnv, shard, javaEnv))
+            local('aws s3 cp s3://topopps-prod-x/application-%s-s%s-worker.yml deploy/worker/config/application-%s-worker.yml' %
+                  (javaEnv, shard, javaEnv))
         else:
             local('cp config/keyset-%s.json deploy/worker/config/keyset.json' % javaEnv)
             local('cp config/application-%s.yml deploy/worker/config/' % javaEnv)
             local('cp config/application-%s-worker.yml deploy/worker/config/' % javaEnv)
 
 
-
-
 # Obtain git_sha from Jenkins git plugin, make sure it's passed along with the code so that
 # uwsgi, djangorq, and and celery can make use of it (e.g. to pass to
 # Sentry for releases)
@@ -398,19 +419,19 @@ def set_git_sha():
     local('git add .')
 
 
-
 # Use either git or tar to create a tarball to distribute.
 # If `dirs` specified, directly create the tarball on those directories.
-# Otherwise, assume that `branch` is specified and use git to create the tarball from that branch.  
+# Otherwise, assume that `branch` is specified and use git to create the tarball from that branch.
 
 @task
-def create_tarball(branch=None, dirs=None, baseDir='.'):  
+def create_tarball(branch=None, dirs=None, baseDir='.'):
     with lcd(baseDir):
         if dirs:
             local('tar -czf %s.tar.gz %s' % (TAR_NAME, dirs))
 
         else:
-            local('find . -path ./\.git -prune -o -name \.gitignore -type f -exec rm -f {} \;')
+            local(
+                'find . -path ./\.git -prune -o -name \.gitignore -type f -exec rm -f {} \;')
             local('echo "%s.tar.*" >> .gitignore' % TAR_NAME)
             local('echo "fabfile.*" >> .gitignore')
             local('rm -rf %s.tar.gz' % TAR_NAME)
@@ -423,10 +444,10 @@ def create_tarball(branch=None, dirs=None, baseDir='.'):
 # legacy synonym for create_tarball, though with `branch` argument required.
 # this is the historical pattern, so `branch` is no longer required in the replacement `create_tarball` task
 
-@task
-def tar_from_git(branch, dirs=None, baseDir='.'):  
-    create_tarball(branch,dirs,baseDir)
 
+@task
+def tar_from_git(branch, dirs=None, baseDir='.'):
+    create_tarball(branch, dirs, baseDir)
 
 
 @task
@@ -582,7 +603,8 @@ def deployParallel(nltkLoad="False", doCollectStatic="True", djangoAdmin="True",
 @task
 def dbmigrate_node(installPath=''):
 
-    pathToUse = '/data/deploy/pending/' + installPath + '/dist' if installPath else '/data/deploy/pending/dist'
+    pathToUse = '/data/deploy/pending/' + installPath + \
+        '/dist' if installPath else '/data/deploy/pending/dist'
 
     with cd(pathToUse):
         run('pwd')
@@ -637,28 +659,31 @@ def update_app_utils(appname, branch, keys=False, reboot=False):
     CONFIG_DIR = "config/"
     ENV_DIR = "environments/"
     KEY_DIR = ("keys/" + ENVIRONMENT) if (keys in TRUTH_VALUES) else ""
-    DIRS_TO_TAR = CONFIG_DIR + " " + ENV_DIR + " " + KEY_DIR
+    CERTS_DIR = "certs/"
+    DIRS_TO_TAR = CONFIG_DIR + " " + ENV_DIR + " " + KEY_DIR + CERTS_DIR
 
     # If it's a shared utils repo, need to reach down into this app's directory
     if os.path.isdir(APP_UTILS_DIR):
         with lcd(APP_UTILS_DIR+"/"):
-            local('git archive %s --format=tar.gz --output=../%s.tar.gz %s %s %s' % (branch, TAR_NAME, CONFIG_DIR, ENV_DIR, KEY_DIR)) 
+            local('git archive %s --format=tar.gz --output=../%s.tar.gz %s %s %s %s' %
+                  (branch, TAR_NAME, CONFIG_DIR, ENV_DIR, KEY_DIR, CERTS_DIR))
     else:
-        local('git archive %s --format=tar.gz --output=%s.tar.gz %s %s %s' % (branch, TAR_NAME, CONFIG_DIR, ENV_DIR, KEY_DIR))
-
+        local('git archive %s --format=tar.gz --output=%s.tar.gz %s %s %s %s' %
+              (branch, TAR_NAME, CONFIG_DIR, ENV_DIR, KEY_DIR, CERTS_DIR))
 
     # and move the tarball to the destination and expand it
     # set the upload path to the home directory
-    UPLOAD_CODE_PATH = "$HOME/" + appname 
+    UPLOAD_CODE_PATH = "/home/ubuntu/" + appname
     cmd = "mkdir -p " + UPLOAD_CODE_PATH + "/" + APP_UTILS_DIR
     run(cmd)
     with cd('%s' % UPLOAD_CODE_PATH):
-        put('%s.tar.gz' % TAR_NAME, '%s.tar.gz' % TAR_NAME, use_sudo=False)
+        put('%s.tar.gz' % TAR_NAME, '%s.tar.gz' % TAR_NAME, use_sudo=True)
         run('tar zxf %s.tar.gz -C %s' % (TAR_NAME, APP_UTILS_DIR))
 
     # run the "instanceType"-command.sh in the appropriate branch
-    cmdToRun = "$HOME/" + appname + "/" + APP_UTILS_DIR + "/config/" + ENVIRONMENT + "/${dc_TAG_Type}-commands.sh"
-    run(cmdToRun)
+    cmdToRun = "/home/ubuntu/" + appname + "/" + APP_UTILS_DIR + \
+        "/config/" + ENVIRONMENT + "/${dc_TAG_Type}-commands.sh"
+    sudo(cmdToRun)
 
     # run deployenv on the instance to get the new values into /etc/enviornmnet
     run("deployenv.sh --type instance -a " + appname + " -e " + ENVIRONMENT)
@@ -678,6 +703,7 @@ def swap_code():
 
     sudo("ln -s $(readlink /data/deploy/pending) /data/deploy/current")
 
+
 @task
 def rollback_code():
     with settings(hide('warnings'), warn_only=True):
@@ -688,12 +714,12 @@ def rollback_code():
         # Point to the previous deploy and delete the one that we're discarding.
         run("(ls -t|grep 20|head -2|ls|grep 20)|sort -r|head -2|tail -1|xargs -I % sudo ln -s /data/deploy/% /data/deploy/current")
         run("(ls -t|grep 20|head -2|ls|grep 20)|sort -r|head -2|tail -1|xargs -I % sudo ln -s /data/deploy/% /data/deploy/pending")
-        run("ls -t|grep 20|head -2|ls|grep 20|sort -r|head -1 |xargs sudo rm -rf")  
+        run("ls -t|grep 20|head -2|ls|grep 20|sort -r|head -1 |xargs sudo rm -rf")
 
 
 @task
 @parallel
-def reload_web(doCollectStatic=None,nginxOnly=False):
+def reload_web(doCollectStatic=None, nginxOnly=False):
     swap_code()
     if doCollectStatic in TRUTH_VALUES:
         collect_static()
@@ -706,7 +732,7 @@ def reload_web(doCollectStatic=None,nginxOnly=False):
 
 @task
 @parallel
-def restart_web(doCollectStatic=None,nginxOnly=False):
+def restart_web(doCollectStatic=None, nginxOnly=False):
     swap_code()
     if doCollectStatic in TRUTH_VALUES:
         collect_static()
@@ -714,7 +740,7 @@ def restart_web(doCollectStatic=None,nginxOnly=False):
     restart_nginx()
 
     if not nginxOnly in TRUTH_VALUES:
-       restart_uwsgi()
+        restart_uwsgi()
 
 
 @task
@@ -757,7 +783,7 @@ def reload_node(processName):
 
 @task
 @parallel
-def reload_script(processName,reloadScriptName="/data/deploy/current/finish-deploy.sh"):
+def reload_script(processName, reloadScriptName="/data/deploy/current/finish-deploy.sh"):
     swap_code()
 
     run("%s %s" % (reloadScriptName, processName))
@@ -839,6 +865,7 @@ def run_app(cmdToRun, stopOnError="True"):
             except FabricException:
                 pass
 
+
 @task
 def sudo_app(cmdToRun, stopOnError="True"):
     if stopOnError in TRUTH_VALUES:
@@ -852,7 +879,7 @@ def sudo_app(cmdToRun, stopOnError="True"):
             except FabricException:
                 pass
 
-@task
-def put_files(src,dest):
-    put(src,dest)
 
+@task
+def put_files(src, dest):
+    put(src, dest)
